@@ -30,7 +30,7 @@ has latitude  => ( is => 'ro' );
 has longitude => ( is => 'ro' );
 has 'time'    => ( is => 'ro', default => '' );
 has timezone  => ( is => 'ro' );
-has offset    => ( is => 'ro' );
+has offset    => ( is => 'ro' ); # Deprecated
 has currently => ( is => 'ro' );
 has minutely  => ( is => 'ro' );
 has hourly    => ( is => 'ro' );
@@ -65,14 +65,7 @@ sub BUILDARGS {
     die "Request to '$url' failed: $response->{status} $response->{reason}\n"
       unless $response->{success};
 
-    my $forecast = decode_json( $response->{content} );
-
-    while ( my ( $key, $val ) = each %args ) {
-        unless ( exists( $forecast->{$key} ) ) {
-            $forecast->{$key} = $val;
-        }
-    }
-    return $forecast;
+    return decode_json( $response->{content} );
 }
 
 1;
@@ -92,12 +85,14 @@ use Data::Dumper;
 
 my $lat  = 43.6667;
 my $long = -79.4167;
+my $time = "1475363709"; # example epoch time (optional)
 my $key = "c9ce1c59d139c3dc62961cbd63097d13"; # example DarkSky API key
 
 my $forecast = DarkSky::API->new(
     key       => $key,
     longitude => $long,
     latitude  => $lat,
+    time      => $time
 );
 
 say "current temperature: " . $forecast->{currently}->{temperature};
